Query

Trait Query 

pub trait Query { }
Query is a simple marker trait that should be placed on query types which we plan to handle with a QueryHandler (a struct that implements HandlesQuery)

Implementors